==> aroundme_0_7_0.zip: aroundme_0_7_0/aroundme/components/core/language/1/barnraiser_01/testimonial.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


// ERRORS
$lang['error']['testimonial_short'] =           "too short";
$lang['error']['testimonial_long'] =            "too long";



// HEADERS
$lang['hdr_write_testimonial'] = 				"write a testimonial";
$lang['hdr_about_testimonials'] = 				"about testimonials";
$lang['hdr_testimonials'] = 					"testimonials";


// TEXTS
$lang['hdr_testimonials_written'] = 			"written";
$lang['hdr_testimonials_received'] = 			"received";

// BODY
$lang['txt_frm_write'] =                        "testimonial";
$lang['txt_frm_send'] =                         "send";
$lang['txt_no_received'] =                      "this person has not received any testimonials";
$lang['txt_no_written'] =                       "this person has not written any testimonials";
$lang['txt_no_recieved_me'] =                   "sorry, you have not received any testimonials";
$lang['txt_no_written_me'] =                    "you have not written any testimonials";
$lang['txt_delete'] =							"delete";
$lang['txt_from'] =								"from:";
$lang['txt_to'] =								"to:";
$lang['txt_about_testimonial'] =				"A testimonial is a ... You can only write a testimonal to someone in your network. The only way to stop a testimonial is to block the user or report it as abuse.we can delete testimonials that we've written<br />"

?>

==> aroundme_0_7_6.zip: aroundme_0_7_6/aroundme/components/core/language/1/barnraiser_01/testimonial.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

// HEADERS
$lang['hdr_write_testimonial'] = 				"write a testimonial";
$lang['hdr_testimonials_written'] = 			"written testimonials";
$lang['hdr_testimonials_received'] = 			"received testimonials";


// ERRORS
$lang['error']['testimonial_short'] =           "Your testimonial is too short (minimum of 10 characters)";
$lang['error']['testimonial_long'] =            "Your testimonial is too long (maximum of 150 characters)";


// BODY
$lang['txt_frm_write'] =                        "testimonial";
$lang['txt_frm_send'] =                         "send";
$lang['txt_no_received'] =                      "this person has not received any testimonials";
$lang['txt_no_written'] =                       "this person has not written any testimonials";
$lang['txt_no_recieved_me'] =                   "sorry, you have not received any testimonials";
$lang['txt_no_written_me'] =                    "you have not written any testimonials";
$lang['txt_delete'] =							"delete";
$lang['txt_from'] =								"from:";
$lang['txt_to'] =								"to:";

?>
